@@ -24,7 +24,7 @@ class DKConnection():
         payload = {'parameters': overrides, "schedule" : "now"}
         response = requests.put(url, headers=headers, data=json.dumps(payload))
         attempts = 1
-        while attempts <= retries and respnse != 200:
+        while attempts <= retries and response.status_code != 200:
             response = requests.put(url, headers=headers, data=json.dumps(payload))
             attemps += 1
         return response
